==> nttpd-0.0.3.tgz: package/lib/statusText.js <==
#!/usr/bin/env node
exports[100] = "Continue";
exports[101] = "Switching Protocols";
exports[102] = "Processing";
exports[122] = "Request-URI too long";
exports[200] = "OK";
exports[201] = "Created";
exports[202] = "Accepted";
exports[203] = "Non-Authoritative Information";
exports[204] = "No Content";
exports[205] = "Reset Content";
exports[206] = "Partial Content";
exports[207] = "Multi-Status";
exports[208] = "IM Used";
exports[300] = "Multiple Choices";
exports[301] = "Moved Permanently";
exports[302] = "Found";
exports[303] = "See Other";
exports[304] = "Not Modified";
exports[305] = "Use Proxy";
exports[306] = "Switch Proxy";
exports[307] = "Temporary Redirect";
exports[400] = "Bad Request";
exports[401] = "Unauthorized";
exports[402] = "Payment Required";
exports[403] = "Forbidden";
exports[404] = "Not Found";
exports[405] = "Method Not Allowed";
exports[406] = "Not Acceptable";
exports[407] = "Proxy Authentication Required";
exports[408] = "Request Timeout";
exports[409] = "Conflict";
exports[410] = "Gone";
exports[411] = "Length Required";
exports[412] = "Precondition Failed";
exports[413] = "Request Entity Too Large";
exports[414] = "Request-URI Too Long";
exports[415] = "Unsupported Media Type";
exports[416] = "Request Range Not Satisfiable";
exports[417] = "Expectation Failed";
exports[418] = "I'm a teapot";
exports[418] = "Unprocessable Entity";
exports[422] = "Bad Request";
exports[423] = "Bad Request";
exports[400] = "Bad Request";
exports[400] = "Bad Request";
exports[400] = "Bad Request";

==> nttpd-0.0.6.tgz: package/lib/statusText.js <==
#!/usr/bin/env node
exports[100] = "Continue";
exports[101] = "Switching Protocols";
exports[102] = "Processing";
exports[122] = "Request-URI too long";
exports[200] = "OK";
exports[201] = "Created";
exports[202] = "Accepted";
exports[203] = "Non-Authoritative Information";
exports[204] = "No Content";
exports[205] = "Reset Content";
exports[206] = "Partial Content";
exports[207] = "Multi-Status";
exports[208] = "IM Used";
exports[300] = "Multiple Choices";
exports[301] = "Moved Permanently";
exports[302] = "Found";
exports[303] = "See Other";
exports[304] = "Not Modified";
exports[305] = "Use Proxy";
exports[306] = "Switch Proxy";
exports[307] = "Temporary Redirect";
exports[400] = "Bad Request";
exports[401] = "Unauthorized";
exports[402] = "Payment Required";
exports[403] = "Forbidden";
exports[404] = "Not Found";
exports[405] = "Method Not Allowed";
exports[406] = "Not Acceptable";
exports[407] = "Proxy Authentication Required";
exports[408] = "Request Timeout";
exports[409] = "Conflict";
exports[410] = "Gone";
exports[411] = "Length Required";
exports[412] = "Precondition Failed";
exports[413] = "Request Entity Too Large";
exports[414] = "Request-URI Too Long";
exports[415] = "Unsupported Media Type";
exports[416] = "Request Range Not Satisfiable";
exports[417] = "Expectation Failed";
exports[418] = "I'm a teapot";
exports[422] = "Unprocessable Entity";
exports[423] = "Locked";
exports[424] = "Failed Dependency";
exports[425] = "Unordered Collection";
exports[426] = "Upgrade Required";
exports[444] = "No Response";
exports[450] = "Blocked by Windows Parental Controls";
exports[499] = "Client Closed Request";
exports[500] = "Internal Server Error";
exports[501] = "Not Implemented";
exports[502] = "Bad Gateway";
exports[503] = "Service Unavailable";
exports[504] = "Gateway Timeout";
exports[505] = "HTTP Version Not Supported";
exports[506] = "Variant Also Negotiates";
exports[507] = "Insufficient Storage";
exports[509] = "Bandwidth Limit Exceeded";
exports[510] = "Not Extended";
